CONSOLE_LOG_ABI = [
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "address", "name": "p0", "type": "address"}],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bool", "name": "p0", "type": "bool"}],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "string", "name": "p0", "type": "string"}],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "bool", "name": "p2", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "uint256", "name": "p0", "type": "uint256"}],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "uint256", "name": "p3", "type": "uint256"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "bool", "name": "p1", "type": "bool"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "uint256", "name": "p0", "type": "uint256"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "string", "name": "p1", "type": "string"},
            {"internalType": "string", "name": "p2", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "bool", "name": "p3", "type": "bool"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "string", "name": "p0", "type": "string"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "address", "name": "p2", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "address", "name": "p0", "type": "address"},
            {"internalType": "address", "name": "p1", "type": "address"},
            {"internalType": "uint256", "name": "p2", "type": "uint256"},
            {"internalType": "string", "name": "p3", "type": "string"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [
            {"internalType": "bool", "name": "p0", "type": "bool"},
            {"internalType": "uint256", "name": "p1", "type": "uint256"},
            {"internalType": "string", "name": "p2", "type": "string"},
            {"internalType": "address", "name": "p3", "type": "address"},
        ],
        "name": "log",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "address", "name": "p0", "type": "address"}],
        "name": "logAddress",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bool", "name": "p0", "type": "bool"}],
        "name": "logBool",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes", "name": "p0", "type": "bytes"}],
        "name": "logBytes",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes1", "name": "p0", "type": "bytes1"}],
        "name": "logBytes1",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes10", "name": "p0", "type": "bytes10"}],
        "name": "logBytes10",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes11", "name": "p0", "type": "bytes11"}],
        "name": "logBytes11",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes12", "name": "p0", "type": "bytes12"}],
        "name": "logBytes12",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes13", "name": "p0", "type": "bytes13"}],
        "name": "logBytes13",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes14", "name": "p0", "type": "bytes14"}],
        "name": "logBytes14",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes15", "name": "p0", "type": "bytes15"}],
        "name": "logBytes15",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes16", "name": "p0", "type": "bytes16"}],
        "name": "logBytes16",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes17", "name": "p0", "type": "bytes17"}],
        "name": "logBytes17",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes18", "name": "p0", "type": "bytes18"}],
        "name": "logBytes18",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes19", "name": "p0", "type": "bytes19"}],
        "name": "logBytes19",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes2", "name": "p0", "type": "bytes2"}],
        "name": "logBytes2",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes20", "name": "p0", "type": "bytes20"}],
        "name": "logBytes20",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes21", "name": "p0", "type": "bytes21"}],
        "name": "logBytes21",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes22", "name": "p0", "type": "bytes22"}],
        "name": "logBytes22",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes23", "name": "p0", "type": "bytes23"}],
        "name": "logBytes23",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes24", "name": "p0", "type": "bytes24"}],
        "name": "logBytes24",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes25", "name": "p0", "type": "bytes25"}],
        "name": "logBytes25",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes26", "name": "p0", "type": "bytes26"}],
        "name": "logBytes26",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes27", "name": "p0", "type": "bytes27"}],
        "name": "logBytes27",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes28", "name": "p0", "type": "bytes28"}],
        "name": "logBytes28",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes29", "name": "p0", "type": "bytes29"}],
        "name": "logBytes29",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes3", "name": "p0", "type": "bytes3"}],
        "name": "logBytes3",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes30", "name": "p0", "type": "bytes30"}],
        "name": "logBytes30",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes31", "name": "p0", "type": "bytes31"}],
        "name": "logBytes31",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes32", "name": "p0", "type": "bytes32"}],
        "name": "logBytes32",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes4", "name": "p0", "type": "bytes4"}],
        "name": "logBytes4",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes5", "name": "p0", "type": "bytes5"}],
        "name": "logBytes5",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes6", "name": "p0", "type": "bytes6"}],
        "name": "logBytes6",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes7", "name": "p0", "type": "bytes7"}],
        "name": "logBytes7",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes8", "name": "p0", "type": "bytes8"}],
        "name": "logBytes8",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "bytes9", "name": "p0", "type": "bytes9"}],
        "name": "logBytes9",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "int256", "name": "p0", "type": "int256"}],
        "name": "logInt",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "string", "name": "p0", "type": "string"}],
        "name": "logString",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
    {
        "inputs": [{"internalType": "uint256", "name": "p0", "type": "uint256"}],
        "name": "logUint",
        "outputs": [],
        "stateMutability": "nonpayable",
        "type": "function",
    },
]



from pydantic_settings import SettingsConfigDict

from ape.api.config import PluginConfig


class ConsoleConfig(PluginConfig):
    plugins: list[str] = []
    """Additional IPython plugins to include in your session."""

    model_config = SettingsConfigDict(extra="allow", env_prefix="APE_CONSOLE_")
